@@ -4,7 +4,7 @@ from typing import Any, Optional, Union
 
 import blessed
 from blessed import Terminal
-from rich import print as rprint
+import rich
 from rich.console import Console
 from rich.layout import Layout
 from rich.panel import Panel
@@ -17,17 +17,14 @@ from .help_layout import HelpLayout, HelpState, random_error_quote
 from .overview_layout import OverviewLayout, OverviewState, PreviewState
 from .stack_layout import StackFrame, StackLayout
 
-version = "1.2.4"
+version = "1.2.5"
 
 # TODO fix explore(namedtuple)
 # TODO methods filter
 # or just a type filter?
 # TODO empty overview layouts for when there are 0 public attributes
 # TODO search filter
-# TODO generate the explorer lines on cachedobject instatiation to speed up processing
-#    - Auto generate ALL renderables on init. docstring, repr (i think already done) type, len, source, etc
 # TODO use inspect.ismethod inspect.ismodule, inspect.isfunction isclass
-# TODO 'i' to fullscreen print rich.inspect
 
 console = Console()
 
@@ -256,6 +253,18 @@ class Explorer:
         elif key == "H":
             help(self.cached_obj.selected_cached_obj.obj)
 
+        elif key == "i":
+            with console.capture() as capture:
+                rich.inspect(self.cached_obj.selected_cached_obj.obj, console=console, methods=True)
+            str_out = capture.get()
+            pydoc.pager(str_out)
+
+        elif key == "I":
+            with console.capture() as capture:
+                rich.inspect(self.cached_obj.selected_cached_obj.obj, console=console, all=True)
+            str_out = capture.get()
+            pydoc.pager(str_out)
+
         # Other ################################################################
 
         # Return selected object
@@ -308,7 +317,7 @@ class Explorer:
             height=self.term.height - 1,
             style="blue",
         )
-        rprint(object_explorer, end="")
+        rich.print(object_explorer, end="")
 
     @property
     def panel_height(self) -> int:
@@ -327,12 +336,12 @@ def explore(obj: Any) -> Any:
     except Exception as e:
         console.print_exception(show_locals=True)
         print()
-        rprint(f"[red]{random_error_quote()}")
+        rich.print(f"[red]{random_error_quote()}")
         formatted_link = f"https://github.com/kylepollina/objexplore/issues/new?assignees=&labels=&template=bug_report.md&title={e}".replace(
             " ", "+"
         )
         print("Please report the issue here:")
-        rprint(f"   [link={formatted_link}][u]{formatted_link}[/u][/link]")
-        rprint(
+        rich.print(f"   [link={formatted_link}][u]{formatted_link}[/u][/link]")
+        rich.print(
             "[yellow italic]Make sure to copy/paste the above traceback to the issue to make the issue quicker to solve!"
         )
